aboutsummaryrefslogtreecommitdiff
path: root/sound/vorbis.h
diff options
context:
space:
mode:
Diffstat (limited to 'sound/vorbis.h')
-rw-r--r--sound/vorbis.h23
1 files changed, 19 insertions, 4 deletions
diff --git a/sound/vorbis.h b/sound/vorbis.h
index 369cd14d01..8ac7354f1f 100644
--- a/sound/vorbis.h
+++ b/sound/vorbis.h
@@ -54,6 +54,9 @@ namespace Audio {
class SeekableAudioStream;
/**
+ * TODO: This is an deprecated interface, it is only for the transition to
+ * SeekableAudioStream in the engines.
+ *
* Create a new AudioStream from the Ogg Vorbis data in the given stream.
* Allows for looping (which is why we require a SeekableReadStream),
* and specifying only a portion of the data to be played, based
@@ -64,14 +67,26 @@ class SeekableAudioStream;
* @param startTime the (optional) time offset in milliseconds from which to start playback
* @param duration the (optional) time in milliseconds specifying how long to play
* @param numLoops how often the data shall be looped (0 = infinite)
* @return a new AudioStream, or NULL, if an error occured
*/
SeekableAudioStream *makeVorbisStream(
Common::SeekableReadStream *stream,
bool disposeAfterUse,
- uint32 startTime = 0,
- uint32 duration = 0,
- uint numLoops = 1);
+ uint32 startTime,
+ uint32 duration,
+ uint numLoops);
+
+/**
+ * Create a new SeekableAudioStream from the Ogg Vorbis data in the given stream.
+ * Allows for seeking (which is why we require a SeekableReadStream).
+ *
+ * @param stream the SeekableReadStream from which to read the Ogg Vorbis data
+ * @param disposeAfterUse whether to delete the stream after use
+ * @return a new SeekableAudioStream, or NULL, if an error occured
+ */
+SeekableAudioStream *makeVorbisStream(
+ Common::SeekableReadStream *stream,
+ bool disposeAfterUse);
} // End of namespace Audio
@@ -64,14 +67,26 @@ class SeekableAudioStream;
* @param duration the (optional) time in milliseconds specifying how long to play
* @param numLoops how often the data shall be looped (0 = infinite)
- * @return a new AudioStream, or NULL, if an error occured
+ * @return a new SeekableAudioStream, or NULL, if an error occured
*/
SeekableAudioStream *makeVorbisStream(